<?php
// Include the database connection
include '../includes/mysqli.php';

// Start session
session_start();

// Check if user is logged in
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'seller') {
    header("Location: ../login.php");
    exit();
}

// Validate property ID
if (!isset($_GET['id']) || empty($_GET['id'])) {
    die("Invalid property ID.");
}

$property_id = $_GET['id'];
$user_id = $_SESSION['user_id'];

// Fetch the property details
$stmt = $conn->prepare("SELECT * FROM properties WHERE id = ? AND user_id = ?");
$stmt->bind_param("ii", $property_id, $user_id);
$stmt->execute();
$property = $stmt->get_result()->fetch_assoc();
$stmt->close();

if (!$property) {
    die("Property not found or you do not have permission to edit it.");
}

// Handle form submission to update property details
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $title = trim($_POST['title']);
    $description = trim($_POST['description']);
    $price = trim($_POST['price']);
    $location = trim($_POST['location']);
    $type = trim($_POST['type']);

    if (empty($title) || empty($description) || empty($price) || empty($location) || empty($type)) {
        $errors[] = "All fields are required.";
    } else {
        $stmt = $conn->prepare("UPDATE properties SET title = ?, description = ?, price = ?, location = ?, type = ? WHERE id = ? AND user_id = ?");
        $stmt->bind_param("ssdssii", $title, $description, $price, $location, $type, $property_id, $user_id);
        if ($stmt->execute()) {
            // Redirect back to seller page
            header("Location: seller.php");
            exit();
        } else {
            $errors[] = "Failed to update property.";
        }
        $stmt->close();
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Property</title>
    <link rel="stylesheet" href="../assets/css/style.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css">
</head>
<body>
    <div class="container mt-5">
        <h1>Edit Property</h1>
        <?php if (!empty($errors)): ?>
            <div class="alert alert-danger">
                <?php foreach ($errors as $error) echo "<p>$error</p>"; ?>
            </div>
        <?php endif; ?>

        <form method="POST">
            <div class="mb-3">
                <label for="title" class="form-label">Title</label>
                <input type="text" id="title" name="title" class="form-control" value="<?= htmlspecialchars($property['title']) ?>" required>
            </div>
            <div class="mb-3">
                <label for="description" class="form-label">Description</label>
                <textarea id="description" name="description" class="form-control" required><?= htmlspecialchars($property['description']) ?></textarea>
            </div>
            <div class="mb-3">
                <label for="price" class="form-label">Price</label>
                <input type="number" id="price" name="price" class="form-control" value="<?= htmlspecialchars($property['price']) ?>" required>
            </div>
            <div class="mb-3">
                <label for="location" class="form-label">Location</label>
                <input type="text" id="location" name="location" class="form-control" value="<?= htmlspecialchars($property['location']) ?>" required>
            </div>
            <div class="mb-3">
                <label for="type" class="form-label">Type</label>
                <select id="type" name="type" class="form-control" required>
                    <option value="Sale" <?= $property['type'] === 'Sale' ? 'selected' : '' ?>>Sale</option>
                    <option value="Rent" <?= $property['type'] === 'Rent' ? 'selected' : '' ?>>Rent</option>
                </select>
            </div>
            <button type="submit" class="btn btn-primary">Update Property</button>
            <a href="seller.php" class="btn btn-secondary">Cancel</a>
        </form>
    </div>
</body>
</html>
