<?php
// Include database connection
include 'includes/mysqli.php';

// Start session
session_start();

// Validate property ID
if (!isset($_GET['id']) || empty($_GET['id'])) {
    die("Invalid property ID.");
}

$property_id = $_GET['id'];

// Fetch property details
$stmt = $conn->prepare("
    SELECT p.*, u.username AS seller_name 
    FROM properties p 
    JOIN users u ON p.user_id = u.id 
    WHERE p.id = ?
");
$stmt->bind_param("i", $property_id);
$stmt->execute();
$property = $stmt->get_result()->fetch_assoc();
$stmt->close();

if (!$property) {
    die("Property not found.");
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?= htmlspecialchars($property['title']) ?> - Property Details</title>
    <link rel="stylesheet" href="assets/css/style.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css">
</head>
<body>
    <div class="container mt-5">
        <h1><?= htmlspecialchars($property['title']) ?></h1>
        <p><strong>Location:</strong> <?= htmlspecialchars($property['location']) ?></p>
        <p><strong>Price:</strong> $<?= number_format($property['price'], 2) ?></p>
        <p><strong>Type:</strong> <?= htmlspecialchars($property['type']) ?></p>
        <p><strong>Description:</strong> <?= htmlspecialchars($property['description']) ?></p>
        <p><strong>Seller:</strong> <?= htmlspecialchars($property['seller_name']) ?></p>
        
        <!-- Property Images -->
        <div class="row">
            <?php 
            $images = explode(',', $property['images']);
            foreach ($images as $image): 
            ?>
                <div class="col-md-4">
                    <img src="assets/house-pictures/<?= htmlspecialchars($image) ?>" alt="Property Image" class="img-fluid">
                </div>
            <?php endforeach; ?>
        </div>
        
        <!-- View Chats Button -->
        <?php if (isset($_SESSION['user_id'])): ?>
            <a href="chat.php?property_id=<?= $property_id ?>" class="btn btn-primary mt-3">View Chats</a>
        <?php else: ?>
            <p class="text-muted mt-3">Log in to view chats.</p>
        <?php endif; ?>
    </div>
</body>
</html>
