<?php
// Include the database connection
include '../includes/mysqli.php';

// Start session
session_start();

// Check if user is logged in
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit();
}

// Fetch the user's details
$user_id = $_SESSION['user_id'];
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $user_id);
$stmt->execute();
$user = $stmt->get_result()->fetch_assoc();
$stmt->close();

// Fetch saved properties
$saved_properties_stmt = $conn->prepare("
    SELECT p.* 
    FROM properties p 
    JOIN favorites f ON p.id = f.property_id 
    WHERE f.user_id = ?");
$saved_properties_stmt->bind_param("i", $user_id);
$saved_properties_stmt->execute();
$saved_properties = $saved_properties_stmt->get_result();
$saved_properties_stmt->close();

// Handle role update (become a seller)
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['become_seller'])) {
    $update_role_stmt = $conn->prepare("UPDATE users SET role = 'seller' WHERE id = ?");
    $update_role_stmt->bind_param("i", $user_id);
    if ($update_role_stmt->execute()) {
        $_SESSION['role'] = 'seller'; // Update session role
        header("Location: seller.php"); // Redirect to seller profile
        exit();
    } else {
        $error = "Failed to update role. Please try again.";
    }
    $update_role_stmt->close();
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Buyer Dashboard - Peterson Real Estate</title>
    <link rel="stylesheet" href="../assets/css/style.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css">
</head>
<body>
    <!-- Navigation Bar -->
    <nav class="navbar navbar-expand-lg">
        <div class="container">
            <a class="navbar-brand" href="../index.php">
                <img src="../assets/images/logo.png" alt="Peterson Real Estate">
            </a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav ms-auto">
                    <li class="nav-item"><a class="nav-link" href="../property.php">Explore Properties</a></li>
                    <li class="nav-item"><a class="nav-link" href="chats.php">Active Chats</a></li>
                    <li class="nav-item"><a class="nav-link" href="saved_properties.php">Saved Properties</a></li>
                    <?php if ($_SESSION['role'] === 'seller'): ?>
                        <li class="nav-item"><a class="nav-link" href="seller.php">Seller Dashboard</a></li>
                    <?php endif; ?>
                    <li class="nav-item"><a class="nav-link" href="../logout.php">Logout</a></li>
                </ul>
            </div>
        </div>
    </nav>

    <!-- Profile Section -->
    <div class="container mt-5">
        <h1>Welcome, <?= htmlspecialchars($user['username']) ?>!</h1>
        <p>Email: <?= htmlspecialchars($user['email']) ?></p>
        <p>Phone: <?= htmlspecialchars($user['phone_number']) ?></p>

        <?php if ($_SESSION['role'] === 'buyer'): ?>
            <form method="POST" action="">
                <button type="submit" name="become_seller" class="btn btn-primary">Become a Seller</button>
            </form>
        <?php elseif ($_SESSION['role'] === 'seller'): ?>
            <a href="seller.php" class="btn btn-success">Go to Seller Dashboard</a>
        <?php endif; ?>

        <?php if (isset($error)): ?>
            <div class="alert alert-danger mt-3">
                <?= htmlspecialchars($error) ?>
            </div>
        <?php endif; ?>
    </div>

    <!-- Saved Properties Section -->
    <div class="container my-5">
        <h2>Your Saved Properties</h2>
        <?php if ($saved_properties->num_rows > 0): ?>
            <div class="row">
                <?php while ($property = $saved_properties->fetch_assoc()): ?>
                    <div class="col-md-4 my-3">
                        <div class="card">
                            <img src="../uploads/<?= htmlspecialchars($property['images']) ?>" alt="Property Image" class="card-img-top">
                            <div class="card-body">
                                <h5 class="card-title"><?= htmlspecialchars($property['title']) ?></h5>
                                <p class="card-text"><?= htmlspecialchars($property['location']) ?></p>
                                <p class="text-muted">$<?= number_format($property['price'], 2) ?></p>
                                <a href="../property.php?id=<?= $property['id'] ?>" class="btn btn-outline-dark btn-sm">View Details</a>
                            </div>
                        </div>
                    </div>
                <?php endwhile; ?>
            </div>
        <?php else: ?>
            <p>No saved properties yet. Start browsing and saving your favorites!</p>
        <?php endif; ?>
    </div>
</body>
</html>
