<?php
include 'mysqli_connect.php'; // Database connection

// Get the ID from the URL
$id = isset($_GET['id']) ? (int) $_GET['id'] : null;
$error_message = "";
$success_message = "";

if ($id) {
    // Fetch the existing comment
    $query = "SELECT name, comment FROM guestbook WHERE id = ?";
    $stmt = $conn->prepare($query);
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $result = $stmt->get_result();
    $row = $result->fetch_assoc();

    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        $name = trim($_POST['name']);
        $comment = trim($_POST['comment']);

        if (!empty($name) && !empty($comment)) {
            $updateQuery = "UPDATE guestbook SET name = ?, comment = ? WHERE id = ?";
            $stmt = $conn->prepare($updateQuery);
            $stmt->bind_param("ssi", $name, $comment, $id);

            if ($stmt->execute()) {
                $success_message = "Comment updated successfully!";
                header("Location: index.php");
                exit();
            } else {
                $error_message = "Error updating comment: " . $conn->error;
            }
        } else {
            $error_message = "All fields are required.";
        }
    }
} else {
    $error_message = "Invalid or missing ID.";
}

mysqli_close($conn);
?>

<!DOCTYPE html>
<html>
<head>
    <title>Update Comment</title>
    <link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>
<?php include 'header.php'; ?>

<div class="container">
    <h1>Update Comment</h1>
    <?php
    if ($error_message) echo "<p class='error'>$error_message</p>";
    if ($success_message) echo "<p class='success'>$success_message</p>";
    ?>
    <form action="" method="POST">
        <label for="name">Name:</label><br>
        <input type="text" id="name" name="name" value="<?php echo htmlspecialchars($row['name'] ?? ''); ?>"><br>
        <label for="comment">Comment:</label><br>
        <textarea id="comment" name="comment" rows="4" cols="50"><?php echo htmlspecialchars($row['comment'] ?? ''); ?></textarea><br>
        <input type="submit" value="Update Comment">
    </form>
</div>

<?php include 'footer.php'; ?>
</body>
</html>